==> scala-client_2.12-1.0.3-sources.jar: com/couchbase/client/scala/search/queries/DocIdQuery.scala <==
/*
 * Copyright (c) 2019 Couchbase, Inc.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.couchbase.client.scala.search.queries

import com.couchbase.client.scala.json.{JsonArray, JsonObject}

/** An FTS query that matches on Couchbase document IDs. Useful to restrict the search space to a list of keys
  * (by using this in an [[AbstractCompoundQuery]] compound query).
  *
  * @param docIds list of document IDs to be restricted against. At least one ID is required.
  *
  * @since 1.0.0
  */
case class DocIdQuery(
    private[scala] val docIds: Seq[String],
    private[scala] val field: Option[String] = None,
    private[scala] val boost: Option[Double] = None
) extends SearchQuery {

  /** The boost parameter is used to increase the relative weight of a clause (with a boost greater than 1) or decrease
    * the relative weight (with a boost between 0 and 1)
    *
    * @param boost the boost parameter, which must be >= 0
    *
    * @return a copy of this, for chaining
    */
  def boost(boost: Double): DocIdQuery = {
    copy(boost = Some(boost))
  }

  override protected def injectParams(input: JsonObject): Unit = {
    input.put("ids", JsonArray(docIds))
    boost.foreach(v => input.put("boost", v))
  }
}

==> scala-client_2.12-1.2.1-sources.jar: com/couchbase/client/scala/search/queries/DocIdQuery.scala <==
/*
 * Copyright (c) 2019 Couchbase, Inc.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.couchbase.client.scala.search.queries

import com.couchbase.client.scala.json.{JsonArray, JsonObject}

/** An FTS query that matches on Couchbase document IDs. Useful to restrict the search space to a list of keys
  * (by using this in an [[AbstractCompoundQuery]] compound query).
  *
  * @param docIds list of document IDs to be restricted against. At least one ID is required.
  *
  * @since 1.0.0
  */
case class DocIdQuery(
    private[scala] val docIds: Seq[String],
    private[scala] val field: Option[String] = None,
    private[scala] val boost: Option[Double] = None
) extends SearchQuery {

  /** The boost parameter is used to increase the relative weight of a clause (with a boost greater than 1) or decrease
    * the relative weight (with a boost between 0 and 1)
    *
    * @param boost the boost parameter, which must be >= 0
    *
    * @return a copy of this, for chaining
    */
  def boost(boost: Double): DocIdQuery = {
    copy(boost = Some(boost))
  }

  override protected def injectParams(input: JsonObject): Unit = {
    input.put("ids", JsonArray(docIds: _*))
    boost.foreach(v => input.put("boost", v))
  }
}
